SpeedrunAPI
===
A library for working with speedrun.coms API

Docs: 'https://speedrunapi.readthedocs.io'

## If you have any questions or suggestions please feel free to contact me about them, for issues please report them on the project repository